@@ -23,10 +23,10 @@ from bandit.core import context as b_context
 from bandit.core import utils
 
 warnings.formatwarning = utils.warnings_formatter
-logger = logging.getLogger(__name__)
+LOG = logging.getLogger(__name__)
 
 
-class BanditTester():
+class BanditTester(object):
     def __init__(self, testset, debug, nosec_lines):
         self.results = []
         self.testset = testset
@@ -67,7 +67,12 @@ class BanditTester():
                 if (result is not None and
                         result.lineno not in self.nosec_lines and
                         temp_context['lineno'] not in self.nosec_lines):
-                    result.fname = temp_context['filename']
+
+                    if isinstance(temp_context['filename'], bytes):
+                        result.fname = temp_context['filename'].decode('utf-8')
+                    else:
+                        result.fname = temp_context['filename']
+
                     if result.lineno is None:
                         result.lineno = temp_context['lineno']
                     result.linerange = temp_context['linerange']
@@ -77,9 +82,7 @@ class BanditTester():
 
                     self.results.append(result)
 
-                    logger.debug(
-                        "Issue identified by %s: %s", name, result
-                    )
+                    LOG.debug("Issue identified by %s: %s", name, result)
                     sev = constants.RANKING.index(result.severity)
                     val = constants.RANKING_VALUES[result.severity]
                     scores['SEVERITY'][sev] += val
@@ -91,10 +94,11 @@ class BanditTester():
                 self.report_error(name, context, e)
                 if self.debug:
                     raise
-        logger.debug("Returning scores: %s", scores)
+        LOG.debug("Returning scores: %s", scores)
         return scores
 
-    def report_error(self, test, context, error):
+    @staticmethod
+    def report_error(test, context, error):
         what = "Bandit internal error running: "
         what += "%s " % test
         what += "on file %s at line %i: " % (
@@ -104,4 +108,4 @@ class BanditTester():
         what += str(error)
         import traceback
         what += traceback.format_exc()
-        logger.error(what)
+        LOG.error(what)
